.. _thanks:

======
Thanks
======

- Facebook and Ben Darnell -- for Tornado and some help, for pre-2.0.0 that used
  Tornado.
- Daniele Varrazzo -- for setproctitle, which was used pre-2.0.0
- The PyPy devs -- for PyPy and some help
- Richard Noble -- for giving me the idea
- David Winterbottom -- ideas/thoughts
